Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AssertTrue ¶
func AssertTrue(b bool)
AssertTrue asserts that b is true. Otherwise, it would log fatal.
func CompareKeys ¶
CompareKeys checks the key without version and then checks the version. a<version> would be sorted higher than aa<version> if we use bytes.compare All keys should have version.
func KeyWithVersion ¶
KeyWithVersion generates a new key by appending ts to key.
func ParseVersion ¶
ParseVersion parses the version from the key bytes.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.